@@ -4,6 +4,8 @@ import win32gui
 import uiautomation as auto
 import datetime
 import easygui
+print("Welcome to Focus-Tracker \nYou can list out your distractions and my duty is to save your time by avoiding them")
+print("To Start please execute : focus_tracker_test -start START")
 
 def url_to_name(url):
     string_list = url.split('/')
